@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.706';
+our $VERSION = '1.709';
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -27,6 +27,7 @@ our $OverrideDefaultProxyClass;
 {
     my $manager = Log::Any::Manager->new();
     sub _manager { return $manager }
+    sub has_consumer { $manager->has_consumer }
 }
 
 sub import {
@@ -134,7 +135,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.706
+version 1.709
 
 =head1 SYNOPSIS
 
@@ -412,6 +413,8 @@ application could do this:
 
 See the L<Log::Any::Adapter> documentation for more details.
 
+To detect if a consumer exists, use C<< Log::Any->has_consumer >>.
+
 =head1 Q & A
 
 =over
@@ -475,7 +478,7 @@ Stephen Thirlwall <sdt@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords bj5004 cm-perl Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish
+=for stopwords bj5004 cm-perl Jonathan Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish
 
 =over 4
 
@@ -489,6 +492,10 @@ cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
+Jonathan <jjrs.pam+github@gmail.com>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
@@ -513,6 +520,10 @@ mephinet <mephinet@gmx.net>
 
 =item *
 
+Michael Conrad <mconrad@intellitree.com>
+
+=item *
+
 Nick Tonkin <1nickt@users.noreply.github.com>
 
 =item *
